#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509
version:              1.7.7
visibility:           public
id:                   crypton-x509-1.7.7-84Z7EDsC5ZWGmFvyN7FzTO
key:                  crypton-x509-1.7.7-84Z7EDsC5ZWGmFvyN7FzTO
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  13f3404be4a7aa2957963b079f15fd07
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-x509-1.7.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-x509-1.7.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-x509-1.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509
hs-libraries:         HScrypton-x509-1.7.7-84Z7EDsC5ZWGmFvyN7FzTO
depends:
    asn1-encoding-0.9.6-AC2d0QUIySCHezK6yIfZL9
    asn1-parse-0.9.5-GBW58EhFQG7MsOhIF4mtM
    asn1-types-0.3.4-569CYcJ0YNxAh1EPDPXM9G base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-7rGtxTEpZ4u1PsW0CXdnJs
    hourglass-0.2.12-7rtgl5Ue6Bw5OEzcXQx398
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    pem-0.2.4-27OSPi7TFZuEYAhIRu13nz transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509/html/crypton-x509.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

